==> zio-aws-elasticsearch_3-5.17.113.1-sources.jar: zio/aws/elasticsearch/model/ListTagsResponse.scala <==
package zio.aws.elasticsearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListTagsResponse(
    tagList: Option[Iterable[zio.aws.elasticsearch.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.ListTagsResponse = {
    import ListTagsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.ListTagsResponse
      .builder()
      .optionallyWith(
        tagList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tagList)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.ListTagsResponse.ReadOnly =
    zio.aws.elasticsearch.model.ListTagsResponse.wrap(buildAwsValue())
}
object ListTagsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.ListTagsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.ListTagsResponse =
      zio.aws.elasticsearch.model.ListTagsResponse(
        tagList.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def tagList: Option[List[zio.aws.elasticsearch.model.Tag.ReadOnly]]
    def getTagList
        : ZIO[Any, AwsError, List[zio.aws.elasticsearch.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tagList", tagList)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.ListTagsResponse
  ) extends zio.aws.elasticsearch.model.ListTagsResponse.ReadOnly {
    override val tagList
        : Option[List[zio.aws.elasticsearch.model.Tag.ReadOnly]] = scala
      .Option(impl.tagList())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticsearch.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.ListTagsResponse
  ): zio.aws.elasticsearch.model.ListTagsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticsearch_3-7.30.22.2-sources.jar: zio/aws/elasticsearch/model/ListTagsResponse.scala <==
package zio.aws.elasticsearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListTagsResponse(
    tagList: Optional[Iterable[zio.aws.elasticsearch.model.Tag]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.ListTagsResponse = {
    import ListTagsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.ListTagsResponse
      .builder()
      .optionallyWith(
        tagList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tagList)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.ListTagsResponse.ReadOnly =
    zio.aws.elasticsearch.model.ListTagsResponse.wrap(buildAwsValue())
}
object ListTagsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.ListTagsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.ListTagsResponse =
      zio.aws.elasticsearch.model.ListTagsResponse(
        tagList.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def tagList: Optional[List[zio.aws.elasticsearch.model.Tag.ReadOnly]]
    def getTagList
        : ZIO[Any, AwsError, List[zio.aws.elasticsearch.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tagList", tagList)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.ListTagsResponse
  ) extends zio.aws.elasticsearch.model.ListTagsResponse.ReadOnly {
    override val tagList
        : Optional[List[zio.aws.elasticsearch.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tagList())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.elasticsearch.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.ListTagsResponse
  ): zio.aws.elasticsearch.model.ListTagsResponse.ReadOnly = new Wrapper(impl)
}
